* ESEG_2013_silc.sps
* 
* Wirth, Heike/Anika Herter (2022): ESEG_2013_silc.sps
* https://www.gesis.org/en/missy/materials/EU-SILC/tools/datahandling
*
* This syntax generates European Socio-Economic Groups (ESEG) based on ISCO08 for EU-SILC Data
* using the P-File (personal data) & R-FILE (personal register data).
* ESEG_1 (less detailed)
* ESEG_2 (detailed)
*
* For details on ESeG please see 
* Meron, Monique et al. (2014)
* Final Report of the ESSnet on the harmonisation and implementation of a 
* European socio-economic classification: 
* European Socio-economic Groups (ESeG)
* Links:
* [0] https://ec.europa.eu/eurostat/cros/content/eseg-report-technicaldocuments_en
* [1] https://ec.europa.eu/eurostat/cros/system/files/ESEG-Report-TechnicalAnnexes_0.zip_en
* [2] https://ec.europa.eu/eurostat/cros/content/eseg_en
* 
* 
* This SPSS-code is free software: you can redistribute it and/or modify
* it under the terms of the GNU Affero General Public License as
* published by the Free Software Foundation, either version 3 of the
* License, or (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU Affero General Public License for more details.
*
* <https://www.gnu.org/licenses/>.
*
* For transforming the EU-SILC CSV-data (as released by Eurostat) into SPSS-data (*.sav),
* please use the corresponding SPSS Command Syntax File published at 
* http://www.gesis.org/missy/eu/setups/EU-SILC
*
* (c) GESIS 04/03/2022
* GESIS - Leibniz Institute for the Social Sciences
* German Microdata Lab 
* Heike Wirth/Anika Herter
* https://www.gesis.org/gml/european-microdata/eu-silc/
* https://www.gesis.org/en/missy/materials/EU-SILC/tools/datahandling
*
* Contact: heike.wirth@gesis.org


* =============================================================================. 
* CONFIGURATION SECTION - Start 

* When using SPSS earlier than V16 you might not use "set unicode"  .

set unicode no.

* The following command should contain the complete path and
  name of the SPSS file, usual file extension "sav".

* Change p_filename to your filename (personal data) (incl. path).
* Change r_filename to your filename  (register personal data) (incl. path).
* Change o_filename to a filename (incl. path) for saving an r-file (rx010) excerpt.

file handle p_file   / name='p_filename'.
file handle r_file   / name='r_filename'.
file handle o_file   / name='o_filename'.


* CONFIGURATION SECTION - End 
* There should be probably nothing to change below this line .
* =============================================================================. 

set decimal dot.

************************************************************************************************
*  Good to know
*
*      There are country specific anonymisation rules in EU-SILC for MT and PT 
*      MT: ISCO08 is provided only for major groups (1-digit)
*      PT: ISCO08 sub-major groups 11, 12, 13 are merged with sub-major group 14  
*         
*
*   => MT: For Malta there is no ESeG generated
*   => PT: For Portugal there is no differentiation between higher and lower Manager 
*
*   Unemployed persons (PL031=5) are classified according to their last job.
*      If there is no information available, unemployed persons are classified as non-active
*      Persons 
*
*   Non-active persons (PL031=6,7,8,10,11) are split into two groups.
*     Group 8: retired people and non-employed people aged 65 or more
*     
*     Group 9: Non-active persons aged less than 65 years who couldn't be classified according to their
*              last job in one of seven ESEG groups
* 
************************************************************************************************

************************************************************************************************
*
* Variables used
* PB020: Country (alphanumeric)
* PL051: ISCO08  (2-digit) current/last; MT: 1-digit; PT: coarsend
* PL040: Status in employment (current/last) => family workers are classified as self-employed
* PL031: self-defined current economic status (current)
* Age = either constructed by using PB140: Year of birth & PB010 (year of data collection)
* RX010: Age at time of interview (prefered option)
* Further variables needed when merging R-File and P-File
* RB010 RB020 RX030 RB030 RX010
* PB010 PB020 PX030 PB030
************************************************************************************************


GET FILE= r_file.
sort cases RB010 RB020 RX030 RB030.
rename variables (RB010 RB020 RX030 RB030 = PB010 PB020 PX030 PB030).
save outfile = o_file
 /keep  PB010 PB020 PX030 PB030 rx010.


GET FILE= p_file.
sort cases PB010 PB020 PX030 PB030.
MATCH FILES  table = o_file / file=*
   /BY  PB010 PB020 PX030 PB030.


compute age = RX010.

compute  isco08 = PL051.
do if (PB020='MT').
recode isco08 (0 thru 99=sysmis).
end if.
execute.
crosstabs isco08 by PB020.


* Generating employment status variable
* Family workers are defined as self-employed .
	compute sta = PL040.
	if (PL040 = 1 or PL040 = 2 or PL040 = 4) sta = 1.
	if (PL040 = 3)  sta = 2 .
	val labs sta 1 'self-employed' 2 'employed'.
	
	crosstabs sta by PL040 .
	
* eseg_1 = aggregated level .
* Assigning eseg to respondents with self-defined current economic status (PL031): self-employed, employed, unemployed, in compulsory military community or service.
	if ((isco08 >=11 and isco08 <=14) and (sta = 1 or sta = 2)) or (isco08 = 01 and sta = 2) and ((PL031 >=1 and PL031 <=5) or (PL031=9)) eseg_1 = 1 .
	if ((isco08 >=21 and isco08 <=26) and (sta = 1 or sta = 2)) and ((PL031 >=1 and PL031 <=5) or (PL031=9)) eseg_1 = 2 .
	if ((isco08 >=31 and  isco08 <=35) or (isco08 = 2)) and (sta = 2)and  ((PL031 >=1 and PL031 <=5) or (PL031=9))  eseg_1 = 3.
	if ((isco08 >=31 and isco08 <=96) and sta = 1) and ((PL031 >=1 and PL031 <=5) or (PL031=9))  eseg_1 = 4 .
	if ((isco08 >=41 and isco08 <=44) or (isco08 =53 or isco08 =54 or isco08 =3)) and (sta = 2) and ((PL031 >=1 and PL031 <=5) or (PL031=9)) eseg_1 = 5 .
	if ((isco08 >=71 and isco08 <=83) and sta = 2) and ((PL031 >=1 and PL031 <=5) or (PL031=9))  eseg_1 = 6.
	if ((isco08 =51 or  isco08 =52) or (isco08 >=61 and isco08 <=63) or (isco08 >=91 and  isco08 <=96)) and (sta = 2) and ((PL031 >=1 and PL031 <=5) or (PL031=9))  eseg_1 = 7.

                 
* Respondents <65, unemployed, no eseg assigned yet are set to eseg 9 'other non-employed persons'.

              if (MISSING (eseg_1) and age < 65 and PL031 = 5)  eseg_1=9.
        

* All other respondents, unemployed and neither in eseg 1-7 nor in eseg 9 are set to eseg 8 'Retired persons'.
                 do if (MISSING(eseg_1) and (PL031 = 5)).  
                compute eseg_1= 8 .
                 end if.


* Respondents  <65 and non-employed according to PL031 (6,8,10,11) are set to eseg 9 'other non-employed persons'.
                 if  (((PL031 =6 or PL031 = 8 or PL031 =10 or PL031 = 11) and age <= 64) or  age <= 14) eseg_1 = 9.
 
* Respondents  >64 and non-employed  are set to eseg 8  'Retired persons'.
               if  (PL031 =7 or (age >=65  and (PL031 =5 or PL031 =6  or PL031 =7 or PL031 =8  or PL031 =10 or PL031 =11 or MISSING (PL031 ))) )  eseg_1 = 8.
        

* ESeG for Malta is set to missing value,  because of country specific anonymisation (ISCO08 only available as 1-digit).
                do if (PB020='MT')  .
               recode eseg_1 (0 thru 99 = sysmis).
                end if.
  
	
value labels eseg_1 
1 'Manager' 
2 'Professionals' 
3 'Technicians and associated professeional employees'
4 'Small entrepreneur' 
5 'Clerks and skilled service employees' 
6 'Industrial skilled employees'
7 'Less skilled employees'  
8 'Retired persons (and non-employed people >=65)'
9 'Other non-employed persons aged < 65'.
execute.
frequencies eseg_1.
execute.



* eseg_2 = detailed level 

* Definition
*1	Managers
*1.1	Higher managerial self-employed  (ISCO 11, 12, 13 and status=se)
*1.2	Lower managerial self-employed  (ISCO 14 and status=se)
*1.3	Higher managerial employees   (ISCO 11, 12, 13 and 01 and status=e)
*1.4	Lower managerial employees   (ISCO 14 and status=e)
*/.
	
	if ((isco08 = 11 or isco08 = 12 or isco08 = 13) and sta = 1) and (eseg_1 > 0 and eseg_1 < 8)  eseg_2 = 11 .
	if ((isco08 = 14 and sta = 1) and (eseg_1 > 0 ) and (eseg_1 < 8)) eseg_2 = 12 .
	if (((isco08 = 01 or isco08 = 11 or isco08 =  12 or isco08 =  13) and sta =2) and eseg_1 > 0 and eseg_1 < 8) eseg_2 = 13.
	if ((isco08 =  14 and sta = 2) and eseg_1 > 0 and eseg_1 < 8) eseg_2 = 14.
	
* Definition
2	Professionals
2.1	Science, engineering and information and communications technology (ICT) professionnals (ISCO 21,25)
2.2	Health professionals  (ISCO 22)
2.3	Business and administration professionals  (ISCO 24)
2.4	Legal, social and cultural professionals  (ISCO 26)
2.5	Teaching professionals  (ISCO 23)  
*/.

	if (isco08 =  21 or isco08 =  25) and (eseg_1 > 0 and eseg_1 < 8)   eseg_2 = 21 .
	if (isco08 = 22) and (eseg_1 > 0 and eseg_1 < 8)   eseg_2 = 22 .
	if (isco08 = 24) and (eseg_1 > 0 and eseg_1 < 8)  eseg_2 = 23 .
	if (isco08 =  26) and (eseg_1 > 0 and eseg_1 < 8)   eseg_2 = 24 .
	if (isco08 = 23) and (eseg_1 > 0 and eseg_1 < 8)  eseg_2 = 25.
	
* Definition
3	Technicians and associated professionals employees (status= e)
3.1	Science, engineering and ICT technicians and associated professionals (ISCO 31, 35)
3.2	Health associate professionals  (ISCO 32)
3.3	Business and administration associate professionals  (ISCO 33)
3.4	Legal, social and cultural associate professionals  (ISCO 34)
3.5	Non-commissioned armed forces officers  (ISCO 02 )
*/.
	
	 if ((isco08 =  31 or isco08 =  35) and sta =  2) and (eseg_1 > 0 and eseg_1 < 8)  eseg_2 = 31.
	if (isco08 =  32 and sta =  2) and (eseg_1 > 0 and eseg_1 < 8)  eseg_2 = 32 .
	 if (isco08 =  33 and sta =  2) and (eseg_1 > 0 and eseg_1 < 8)  eseg_2 = 33.
	if (isco08 =  34 and sta =  2) and (eseg_1 > 0 and eseg_1 < 8) eseg_2 = 34 .
	if (isco08 =  02 and sta =  2) and (eseg_1 > 0 and eseg_1 < 8) eseg_2 = 35 .
	
* Definition
4	Small entrepreneurs  (status= se)
4.1	Skilled agricultural self employed workers  (ISCO 6)
4.2	Technicians, clerical support, services and sales self employed workers  (ISCO 3, 4, 5)
4.3	Craft and related trades self employed workers  (ISCO 7, 8, 9)
*/

	if ((isco08 >=61 and isco08 <=63) and sta= 1) and (eseg_1 > 0 and eseg_1 < 8) eseg_2 = 41. 
	if ((isco08 >=31 and isco08 <=54) and sta= 1) and (eseg_1 > 0 and eseg_1 < 8)  eseg_2 = 42 .
	if ((isco08 >=71 and isco08 <=96) and sta= 1) and (eseg_1 > 0 and eseg_1 < 8)  eseg_2 = 43 .
	
* Definition
5	Clerks and skilled service workers  (status=e)
5.1	General and numerical clerks and other clerical support employees  (ISCO 41, 43, 44)
5.2	Customer services clerks  (ISCO 42)
5.3	Personal care employees  (ISCO 53)
5.4	Armed forced occupations and protective service employees  (ISCO 03 and ISCO 54)
*/

	if ((isco08 = 41 or isco08 = 43 or isco08 =  44) and sta =  2) and (eseg_1 > 0 and eseg_1 < 8) eseg_2 = 51. 
	if (isco08 =  42 and sta =  2) and (eseg_1 > 0 and eseg_1 < 8) eseg_2 = 52. 
	if (isco08 =  53 and sta =  2) and (eseg_1 > 0 and eseg_1 < 8) eseg_2 = 53. 
	if ((isco08 = 03 or isco08 =  54) and sta=  2) and (eseg_1 > 0 and eseg_1 < 8)  eseg_2 = 54. 
	
* Definition
6	Industrial and agricultural employees  (status= e)
6.1	Building and related trade employees  (ISCO 71)
6.2	Food processing, wood working, garment employees  (ISCO 75)
6.3	Metal, machinery, handicraft, printing, electrical and electronic trades employees  (ISCO 72, 73, 74)
6.4	Stationary plant and machine operators and assemblers  (ISCO 81, 82)
6.5	Drivers  (ISCO 83)
*/

	if (isco08 =  71 and sta =  2) and (eseg_1 > 0 and eseg_1 < 8)   eseg_2 = 61 .
	if (isco08 = 75 and sta = 2) and (eseg_1 > 0 and eseg_1 < 8)   eseg_2 = 62 .
	if ((isco08 =72 or isco08 = 73 or isco08 = 74) and sta = 2) and (eseg_1 > 0 and eseg_1 < 8)   eseg_2 = 63 .
	if ((isco08 =81 or isco08 = 82) and sta = 2) and (eseg_1 > 0 and eseg_1 < 8)   eseg_2 = 64 .
	if (isco08 = 83 and sta = 2) and (eseg_1 > 0 and eseg_1 < 8)   eseg_2 = 65 .

* Definition
7	Less skilled workers (status= e)
7.1	Personal services and sales employees (ISCO 51, 52)
7.2	Blue collar employees and food preparation assistants in elementary occupations (ISCO 92, 93, 94, 96)  
7.3	Cleaners and helpers and services employees in elementary occupations (ISCO 91, 95)
7.4	Agricultural employees  (ISCO  6)
*/AND

	 if ((isco08 = 51 or isco08 = 52) and sta = 2) and (eseg_1 > 0 and eseg_1 < 8)  eseg_2 = 71.
	if ((isco08 = 92 or isco08 = 93 or isco08 = 94 or isco08 = 96) and sta = 2) and (eseg_1 > 0 and eseg_1 < 8) eseg_2 = 72 .
	if ((isco08 = 91 or isco08 = 95) and sta = 2) and (eseg_1 > 0 and eseg_1 < 8) eseg_2 = 73 .
	if ((isco08 >=61 and isco08 <=63) and sta = 2) and (eseg_1 > 0 and eseg_1 < 8)  eseg_2 = 74 .
	
* Definition
8	Retired persons (and persons not employed  65 years or more)
8.1	Retired Managers
8.2	Retired professionals
8.3	Retired technicians and associate professionals
8.4	Retired small entrepreneurs
8.5	Retired skilled service workers 
8.6	Retired skilled blue-collars
8.7	Retired less skilled workers
8.8	Other inactive aged 65 or more
*/

	if ((((isco08 >=11 and isco08 <=14) and(sta = 1 or sta = 2)) or (isco08 = 01 and sta = 2)) and eseg_1 = 8)   eseg_2 = 81 .
	if (((isco08 >=21 and isco08 <=26) and (sta = 2 or sta = 1)) and eseg_1 = 8 ) eseg_2 = 82 .
	if ((((isco08 >=31 and isco08 <=35) and sta = 2) or (isco08 = 02 and sta = 2)) and eseg_1 = 8 )  eseg_2 = 83 .
	if (((isco08 >=31 and isco08 <=96) and sta = 1) and eseg_1 = 8 )  eseg_2 = 84 .
	if ((((isco08 >=41 and isco08 <=44)| isco08 = 03 or isco08 = 53 or isco08 = 54) and sta = 2) and eseg_1 = 8 )  eseg_2 = 85 .
	if (((isco08 >=71 and isco08 <=83) and sta = 2) and eseg_1 = 8 ) eseg_2 = 86 .
	if ((((isco08 >=61 and isco08 <=63) or (isco08 >=91 and isco08 <=96) or isco08 = 51 or isco08 = 52) and sta = 2) and eseg_1 = 8 )  eseg_2 = 87 .
	if (missing(eseg_2) and eseg_1 = 8 ) eseg_2 = 88 .
	
	
* Definition
9	Other non employed persons
9.1	Students
9.2	Permanently disabled 
9.3	Unemployed not elsewhere classified 
9.4	Other inactive aged less than 65 years
*/AND

	 if (PL031 = 6 and eseg_1 = 9) eseg_2 = 91.
	if (PL031 = 8 and eseg_1 = 9)  eseg_2 = 92 .
	if (PL031 = 5 and eseg_1 = 9)  eseg_2 = 93 .
	if ((PL031 = 9 or PL031 = 10 or PL031 = 11) and eseg_1 = 9)  eseg_2 = 94 .

                 do if (missing(eseg_1))  .
                 recode eseg_2 (0 thru 99 = sysmis).
                 end if.
  
	
value labels eseg_2
11 "Higher managerial self-employed" 
12 "Lower managerial self-employed" 
13 "Higher managerial employees"
14 "Lower managerial employees" 
21 "Science, engineering and information and communications technology (ICT) professionals" 
22 "Health professionals" 
23 "Business and administration professionals" 
24 "Legal, social and cultural professionals" 
25 "Teaching professionals" 
31 "Science, engineering and ICT technicians and associated professionals" 
32 "Health associate professionals" 
33 "Business and administration associate professionals"
34 "Legal, social and cultural associate professionals" 
35 "Non-commissioned armed forces officers"
41 "Skilled agricultural self-employed workers" 
42 "Technicians, clerical support, services and sales self-employed workers" 
43 "Craft and related trades self-employed workers" 
51 "General and numerical clerks and other clerical support employees" 
52 "Customer services clerks" 
53 "Personal care employees" 
54 "Armed forced occupations and protective service employees" 
61 "Building and related trade employees" 
62 "Food processing, wood working, garment employees" 
63 "Metal, machinery, handicraft, printing, electrical and electronic trades employees" 
64 "Stationary plant and machine operators and assemblers" 
65 "Drivers" 
71 "Personal services and sales employees"
72 "Blue collar employees and food preparation assistants in elementary occupations" 
73 "Cleaners and helpers and services employees in elementary occupations" 
74 "Agricultural employees" 
81 "Retired Managers" 
82 "Retired professionals" 
83 "Retired technicians and associate professionals"
84 "Retired small entrepreneurs"
85 "Retired skilled white collars" 
86 "Retired skilled blue-collars"
87 "Retired less skilled workers" 
88 "Other inactive aged 65 or more" 
91 "Students" 
92 "Permanently disabled"
93 "Unemployed not elsewhere classified"
94 "Other inactive aged less than 65 years" .


* ESeG for Malta is set to missing value,  because of country specific anonymisation (ISCO08 only available as 1-digit).

 do if (PB020="MT")  .
 recode eseg_2 (0 thru 99 = sysmis).
 end if.

freq eseg_1  eseg_2.

ERASE file = o_file.


